==> haskell-hxt-unicode-9.0.2.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-unicode
version: 9.0.2.4
id: hxt-unicode-9.0.2.4-AEIThHBnNFILy3JikxDDI3
key: hxt-unicode-9.0.2.4-AEIThHBnNFILy3JikxDDI3
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Unicode en-/decoding functions for utf8, iso-latin-* and other encodings
description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.
category: Text
author: Uwe Schmidt
exposed: True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode
abi: 090d37d9881f3e34b24ca2f70fa610c4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-unicode-9.0.2.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-unicode-9.0.2.4
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hxt-unicode-9.0.2.4
hs-libraries: HShxt-unicode-9.0.2.4-AEIThHBnNFILy3JikxDDI3
depends:
    base-4.9.0.0 hxt-charproperties-9.2.0.1-L1rhanzXQ304SfBOSkeXkX
haddock-interfaces: /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html: /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-unicode-9.0.2.4-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-unicode
version: 9.0.2.4
id: hxt-unicode-9.0.2.4-91NbsYmAW3YHFFSyOss7u4
key: hxt-unicode-9.0.2.4-91NbsYmAW3YHFFSyOss7u4
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Unicode en-/decoding functions for utf8, iso-latin-* and other encodings
description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.
category: Text
author: Uwe Schmidt
exposed: True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode
abi: c709bfe88845b32f5aea37cb902b173e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hxt-unicode-9.0.2.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/hxt-unicode-9.0.2.4
hs-libraries: HShxt-unicode-9.0.2.4-91NbsYmAW3YHFFSyOss7u4
depends:
    base-4.9.1.0 hxt-charproperties-9.2.0.1-48OogeCJMUc1lcYcm9OQtr
haddock-interfaces: /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html: /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
